@@ -1,4 +1,4 @@
-from typing import Any, ClassVar, Generator, get_origin, get_args
+from typing import Any, Literal, ClassVar, Generator, get_origin, get_args
 
 import logging
 logger = logging.getLogger(__name__)
@@ -205,11 +205,13 @@ class SQLConfig(AbsConfig):
     """
     An obscured declaration is intentional here.
 
-    This is simplest way I found so far to 'replace' protected field with a dummy during instantiation.
+    NOTE: Mind the `driver` field value. It is better be (if available) an ODBC driver with specified version, ex. 'ODBC Driver 17 for SQL Server'. Generic values like 'SQL Server' will seriously limit turbodbc capabilities.
+
+    This is "simplest" way I found so far to 'replace' protected field with a dummy during instantiation.  
 
     Ex. with `server` attributes:
 
-    server : is a dummy-field that is used on init and gets added to repr. This gets overwriten with property attribute. So it is only here to look pretty.
+    server : is a dummy-field that is used on init and gets added to repr. This gets overwriten with property attribute right away. So it is only here to look pretty.
 
     _server : a field that holds actual value for an instance
 
@@ -237,7 +239,7 @@ class SQLConfig(AbsConfig):
     
     driver: str = field(default=None, compare=False)
     _driver: str | None = field(init=False, repr=False, default=None)
-    default_driver: ClassVar[str] = field(init=False, default=r'SQL Server', compare=False)
+    default_driver: ClassVar[str] = field(init=False, default=r'ODBC Driver 17 for SQL Server', compare=False)
     @config_property
     def driver(self) -> str | None:
         return self._driver
@@ -245,11 +247,11 @@ class SQLConfig(AbsConfig):
     def driver(self, driver: str):
         self._driver = driver
     
-    trusted_connection: bool  = field(default=None, compare=False)
-    _trusted_connection: bool | None = field(init=False, repr=False, default=None)
-    default_trusted_connection: ClassVar[bool] = field(init=False, default=True, compare=False)
+    trusted_connection: bool | Literal['YES', 'NO']  = field(default=None, compare=False)
+    _trusted_connection: bool | Literal['YES', 'NO'] | None = field(init=False, repr=False, default=None)
+    default_trusted_connection: ClassVar[bool | Literal['YES', 'NO']] = field(init=False, default='YES', compare=False)
     @config_property
-    def trusted_connection(self) -> bool | None:
+    def trusted_connection(self) -> bool | Literal['YES', 'NO'] | None:
         return self._trusted_connection
     @trusted_connection.setter
     def trusted_connection(self, trusted_connection: bool):
@@ -331,7 +333,7 @@ class Query:
     def __post_init__(self):
 
         try:
-            with io.open(self.stmt, 'r') as file:
+            with io.open(self.stmt, mode='rt+', encoding='utf-8') as file:
                 self.stmt = file.read()
             # logger.debug('Statement is a file path')
         # except FileNotFoundError:
@@ -342,10 +344,11 @@ class Query:
             pass
         # remove inline comments
         self.stmt = re.sub(r'--.*?\n', '', self.stmt)
-        # logger.debug(f"cleaned up statement:\n{self.stmt}")
+        logger.debug(f"cleaned up statement:\n{self.stmt}")
 
         # self.placeholders = re.findall(r'\?', self.stmt)
         # logger.debug(f"placeholders:\n{self.placeholders}")
+        self.update_stmt()
     
    
     def execute(self, cursor: Cursor | None = None) -> pd.DataFrame | None:
@@ -403,6 +406,8 @@ class Mixin():
     def __iter__(self):
         return iter(self.__dict__)
 
+    def __setitem__(self, __name: str, __value) -> None:
+        self.__dict__[__name] = __value
 
     def __getitem__(self, __name: str) -> Any:
         return self.__dict__[__name]
